﻿using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

// Writing Adobe Swatch Exchange (ase) files using C#
// http://www.cyotek.com/blog/writing-adobe-swatch-exchange-ase-files-using-csharp

namespace AdobeSwatchExchangeLoader
{
  public partial class CompareResultsDialog : Form
  {
    #region Constructors

    public CompareResultsDialog()
    {
      this.InitializeComponent();
    }

    public CompareResultsDialog(string sourceFileName)
      : this()
    {
      string destinationFileName;

      destinationFileName = Path.GetTempFileName();

      try
      {
        AseDocument document;
        AseCompareResult compareResult;

        document = new AseDocument();
        document.Load(sourceFileName);

        document.Save(destinationFileName);

        compareResult = AseComparer.Compare(sourceFileName, destinationFileName);

        if (compareResult == AseCompareResult.Mismatch)
        {
          resultLabel.Text = "Files do not match.";
          resultLabel.BackColor = Color.Red;
        }
        else if (compareResult == AseCompareResult.ColorMatch)
        {
          resultLabel.Text = "Byte data of files does not match, but colour information is a match.";
          resultLabel.BackColor = Color.Orange;
          resultLabel.ForeColor = Color.Black;
        }

        sourceAseHexViewer.FileName = sourceFileName;
        destinationAseHexViewer.FileName = destinationFileName;
      }
      finally
      {
        File.Delete(destinationFileName);
      }
    }

    #endregion

    #region Methods

    private void closeButton_Click(object sender, EventArgs e)
    {
      this.Close();
    }

    private void destinationAseHexViewer_TopRowChanged(object sender, EventArgs e)
    {
      this.SyncRow(destinationAseHexViewer, sourceAseHexViewer);
    }

    private void sourceAseHexViewer_TopRowChanged(object sender, EventArgs e)
    {
      this.SyncRow(sourceAseHexViewer, destinationAseHexViewer);
    }

    private void SyncRow(AseHexViewer source, AseHexViewer dest)
    {
      int row;

      row = source.TopRow;
      if (dest.Rows > row)
      {
        dest.TopRow = row;
        dest.Refresh();
      }
    }

    #endregion
  }
}
