﻿using System.Text;

// Writing Adobe Swatch Exchange (ase) files using C#
// http://www.cyotek.com/blog/writing-adobe-swatch-exchange-ase-files-using-csharp

// Sample palettes used in this example program from:
// http://www.sherwin-williams.com/architects-specifiers-designers/color/color-tools/downloadable-color-palettes/
// http://www.colourlovers.com/palette/3899568/Blue_Lace
// http://www.colourlovers.com/palette/92095/Giant_Goldfish
// http://www.pixeljoint.com/forum/forum_posts.asp?TID=12795
// http://www.pixeljoint.com/forum/forum_posts.asp?TID=16247
// http://androidarts.com/palette/16pal.htm

namespace AdobeSwatchExchangeLoader
{
  internal static class SampleDocuments
  {
    #region Static Methods

    public static void MakeArne16GlobalSample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Colors = SamplePalettes.CreateArne16Palette();

      sample.Save(fileName);
    }

    public static void MakeArne16Sample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "Arne 16 v20",
                          Colors = SamplePalettes.CreateArne16Palette()
                        });

      sample.Save(fileName);
    }

    public static void MakeCombinedSample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "调色板",
                          Colors = SamplePalettes.CreateBlackAndWhitePalette(),
                          ExtraData = Encoding.ASCII.GetBytes("EXAMPLE DATA APPENDED TO GROUP")
                        });

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "Arne 16 v20",
                          Colors = SamplePalettes.CreateArne16Palette()
                        });

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 16",
                          Colors = SamplePalettes.CreateDawnBringer16Palette()
                        });

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 32",
                          Colors = SamplePalettes.CreateDawnBringer32Palette()
                        });

      sample.Save(fileName);
    }

    public static void MakeDb16GlobalSample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Colors = SamplePalettes.CreateDawnBringer16Palette();

      sample.Save(fileName);
    }

    public static void MakeDb16Sample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 16",
                          Colors = SamplePalettes.CreateDawnBringer16Palette()
                        });

      sample.Save(fileName);
    }

    public static void MakeDb32GlobalSample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Colors = SamplePalettes.CreateDawnBringer32Palette();

      sample.Save(fileName);
    }

    public static void MakeDb32Sample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 32",
                          Colors = SamplePalettes.CreateDawnBringer32Palette()
                        });

      sample.Save(fileName);
    }

    public static void MakeDbSample(string fileName)
    {
      AseDocument sample;

      sample = new AseDocument();

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 16",
                          Colors = SamplePalettes.CreateDawnBringer16Palette()
                        });

      sample.Groups.Add(new ColorGroup
                        {
                          Name = "DawnBringer 32",
                          Colors = SamplePalettes.CreateDawnBringer32Palette()
                        });

      sample.Save(fileName);
    }

    #endregion
  }
}
