﻿using System.Drawing;
using System.Text;

// Writing Adobe Swatch Exchange (ase) files using C#
// http://www.cyotek.com/blog/writing-adobe-swatch-exchange-ase-files-using-csharp

// Sample palettes used in this example program from:
// http://www.sherwin-williams.com/architects-specifiers-designers/color/color-tools/downloadable-color-palettes/
// http://www.colourlovers.com/palette/3899568/Blue_Lace
// http://www.colourlovers.com/palette/92095/Giant_Goldfish
// http://www.pixeljoint.com/forum/forum_posts.asp?TID=12795
// http://www.pixeljoint.com/forum/forum_posts.asp?TID=16247
// http://androidarts.com/palette/16pal.htm

namespace AdobeSwatchExchangeLoader
{
  internal static class SamplePalettes
  {
    #region Static Methods

    /// <summary>
    /// Creates the Arne 16 v20 palette.
    /// </summary>
    /// <remarks>http://androidarts.com/palette/16pal.htm</remarks>
    public static ColorEntryCollection CreateArne16Palette()
    {
      ColorEntryCollection results;

      results = new ColorEntryCollection();

      results.Add(new ColorEntry("VOID", 0, 0, 0));
      results.Add(new ColorEntry("ASH", 157, 157, 157));
      results.Add(new ColorEntry("BLIND", 255, 255, 255));
      results.Add(new ColorEntry("BLOODRED", 190, 38, 51));
      results.Add(new ColorEntry("PIGMEAT", 224, 111, 139));
      results.Add(new ColorEntry("OLDPOOP", 73, 60, 43));
      results.Add(new ColorEntry("NEWPOOP", 164, 100, 34));
      results.Add(new ColorEntry("BLAZE", 235, 137, 49));
      results.Add(new ColorEntry("ZORNSKIN", 247, 226, 107));
      results.Add(new ColorEntry("SHADEGREEN", 47, 72, 78));
      results.Add(new ColorEntry("LEAFGREEN", 68, 137, 26));
      results.Add(new ColorEntry("SLIMEGREEN", 163, 206, 39));
      results.Add(new ColorEntry("NIGHTBLUE", 27, 38, 50));
      results.Add(new ColorEntry("SEABLUE", 0, 87, 132));
      results.Add(new ColorEntry("SKYBLUE", 49, 162, 242));
      results.Add(new ColorEntry("CLOUDBLUE", 178, 220, 239));

      return results;
    }

    public static ColorEntryCollection CreateBlackAndWhitePalette()
    {
      ColorEntryCollection results;

      results = new ColorEntryCollection();

      results.Add(new ColorEntry(Color.White)
                  {
                    ExtraData = Encoding.ASCII.GetBytes("EXAMPLE DATA APPENDED TO FIRST COLOR")
                  });
      results.Add(new ColorEntry(Color.Black)
                  {
                    ExtraData = Encoding.ASCII.GetBytes("EXAMPLE DATA APPENDED TO SECOND COLOR")
                  });

      return results;
    }

    /// <summary>
    /// Creates the DB16 palette.
    /// </summary>
    /// <remarks>http://www.pixeljoint.com/forum/forum_posts.asp?TID=12795</remarks>
    public static ColorEntryCollection CreateDawnBringer16Palette()
    {
      ColorEntryCollection results;

      results = new ColorEntryCollection();

      results.Add(new ColorEntry(20, 12, 28));
      results.Add(new ColorEntry(68, 36, 52));
      results.Add(new ColorEntry(48, 52, 109));
      results.Add(new ColorEntry(78, 74, 78));
      results.Add(new ColorEntry(133, 76, 48));
      results.Add(new ColorEntry(52, 101, 36));
      results.Add(new ColorEntry(208, 70, 72));
      results.Add(new ColorEntry(117, 113, 97));
      results.Add(new ColorEntry(89, 125, 206));
      results.Add(new ColorEntry(210, 125, 44));
      results.Add(new ColorEntry(133, 149, 161));
      results.Add(new ColorEntry(109, 170, 44));
      results.Add(new ColorEntry(210, 170, 153));
      results.Add(new ColorEntry(109, 194, 202));
      results.Add(new ColorEntry(218, 212, 94));
      results.Add(new ColorEntry(222, 238, 214));

      return results;
    }

    /// <summary>
    /// Creates the DB32 palette.
    /// </summary>
    /// <remarks>http://www.pixeljoint.com/forum/forum_posts.asp?TID=16247</remarks>
    public static ColorEntryCollection CreateDawnBringer32Palette()
    {
      ColorEntryCollection results;

      results = new ColorEntryCollection();

      results.Add(new ColorEntry(0, 0, 0));
      results.Add(new ColorEntry(34, 32, 52));
      results.Add(new ColorEntry(69, 40, 60));
      results.Add(new ColorEntry(102, 57, 49));
      results.Add(new ColorEntry(143, 86, 59));
      results.Add(new ColorEntry(223, 113, 38));
      results.Add(new ColorEntry(217, 160, 102));
      results.Add(new ColorEntry(238, 195, 154));
      results.Add(new ColorEntry(251, 242, 54));
      results.Add(new ColorEntry(153, 229, 80));
      results.Add(new ColorEntry(106, 190, 48));
      results.Add(new ColorEntry(55, 148, 110));
      results.Add(new ColorEntry(75, 105, 47));
      results.Add(new ColorEntry(82, 75, 36));
      results.Add(new ColorEntry(50, 60, 57));
      results.Add(new ColorEntry(63, 63, 116));
      results.Add(new ColorEntry(48, 96, 130));
      results.Add(new ColorEntry(91, 110, 225));
      results.Add(new ColorEntry(99, 155, 255));
      results.Add(new ColorEntry(95, 205, 228));
      results.Add(new ColorEntry(203, 219, 252));
      results.Add(new ColorEntry(255, 255, 255));
      results.Add(new ColorEntry(155, 173, 183));
      results.Add(new ColorEntry(132, 126, 135));
      results.Add(new ColorEntry(105, 106, 106));
      results.Add(new ColorEntry(89, 86, 82));
      results.Add(new ColorEntry(118, 66, 138));
      results.Add(new ColorEntry(172, 50, 50));
      results.Add(new ColorEntry(217, 87, 99));
      results.Add(new ColorEntry(215, 123, 186));
      results.Add(new ColorEntry(143, 151, 74));
      results.Add(new ColorEntry(138, 111, 48));

      return results;
    }

    #endregion
  }
}
